==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/TransitiveTargets.h <==
// public class soot.jimple.toolkits.callgraph.TransitiveTargets

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 890d073866efe1b0 soot_jimple_toolkits_callgraph_TransitiveTargets

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_TransitiveTargets_H_
#define _JC_soot_jimple_toolkits_callgraph_TransitiveTargets_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_ArrayList$object;
struct _jc_java_util_Iterator$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_jimple_toolkits_callgraph_Filter$object;
struct _jc_soot_util_NumberedSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$sub_refs	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$refs	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$nonrefs	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vmethods	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtable	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtype	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method$_init$df901ac5be0f618e(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *);
extern void _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method$_init$0ddbc9f2cf20179b(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method$iterator$36731e7fd23a6e0c(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method$iterator$1877eaf17a4b7cc4(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_soot_SootMethod$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method$iterator$98ad4056f2ee07bd(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method$iterator$8b6e51147de1d73c(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_soot_util_NumberedSet$object *, struct _jc_java_util_ArrayList$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method_info$iterator$36731e7fd23a6e0c;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method_info$iterator$1877eaf17a4b7cc4;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method_info$iterator$98ad4056f2ee07bd;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method_info$iterator$8b6e51147de1d73c;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vmethods {
	struct _jc_object	*(*iterator$36731e7fd23a6e0c)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_object *);
	struct _jc_object	*(*iterator$1877eaf17a4b7cc4)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_soot_SootMethod$object *);
	struct _jc_object	*(*iterator$98ad4056f2ee07bd)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_object *);
	struct _jc_object	*(*iterator$8b6e51147de1d73c)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_soot_util_NumberedSet$object *, struct _jc_java_util_ArrayList$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vmethods	soot_jimple_toolkits_callgraph_TransitiveTargets;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$sub_refs {
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*cg;
	struct _jc_soot_jimple_toolkits_callgraph_Filter$object	*filter;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$refs {
    _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$sub_refs	soot_jimple_toolkits_callgraph_TransitiveTargets;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$sub_nonrefs	soot_jimple_toolkits_callgraph_TransitiveTargets;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object {
	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtype _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_TransitiveTargets, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_TransitiveTargets_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/TransitiveTargets.h <==
// public class soot.jimple.toolkits.callgraph.TransitiveTargets

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 890d073866efe1b0 soot_jimple_toolkits_callgraph_TransitiveTargets

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_TransitiveTargets_H_
#define _JC_soot_jimple_toolkits_callgraph_TransitiveTargets_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_ArrayList$object;
struct _jc_java_util_Iterator$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_jimple_toolkits_callgraph_Filter$object;
struct _jc_soot_util_NumberedSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$sub_refs	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$refs	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$nonrefs	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vmethods	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtable	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtype	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method$_init$df901ac5be0f618e(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method$_init$0ddbc9f2cf20179b(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method$iterator$36731e7fd23a6e0c(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method$iterator$1877eaf17a4b7cc4(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method$iterator$98ad4056f2ee07bd(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method$iterator$8b6e51147de1d73c(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_soot_util_NumberedSet$object *, struct _jc_java_util_ArrayList$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method_info$iterator$36731e7fd23a6e0c;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method_info$iterator$1877eaf17a4b7cc4;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method_info$iterator$98ad4056f2ee07bd;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$method_info$iterator$8b6e51147de1d73c;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vmethods {
	struct _jc_object	*(*iterator$36731e7fd23a6e0c)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*iterator$1877eaf17a4b7cc4)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*iterator$98ad4056f2ee07bd)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*iterator$8b6e51147de1d73c)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object *, struct _jc_soot_util_NumberedSet$object *, struct _jc_java_util_ArrayList$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vmethods	soot_jimple_toolkits_callgraph_TransitiveTargets;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$sub_refs {
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*cg;
	struct _jc_soot_jimple_toolkits_callgraph_Filter$object	*filter;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$refs {
    _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$sub_refs	soot_jimple_toolkits_callgraph_TransitiveTargets;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$sub_nonrefs	soot_jimple_toolkits_callgraph_TransitiveTargets;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$object {
	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_TransitiveTargets$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$vtype _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_TransitiveTargets, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_TransitiveTargets$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_TransitiveTargets_H_ */
